@@ -55,12 +55,7 @@ fn main() {
     println!("[+] key prefix for System Account map is {:?}", result);
 
     // get StorageDoubleMap
-    let result: u32 = api
-        .get_storage_value("TemplateModule", "Something", None)
-        .unwrap()
-        .unwrap()
-        .decode()
-        .unwrap();
+    let result = api.get_storage_value("TemplateModule", "Something", None);
     println!("[+] some double map (1,2) should be 3. Is {:?}", result);
 
     // get Alice's AccountNonce with api.get_nonce()
