@@ -16,7 +16,7 @@
 
 use std::{collections::HashMap, convert::TryFrom, marker::PhantomData, str::FromStr};
 
-use codec::{Decode, Encode};
+use codec::Encode;
 
 use frame_metadata::{
     DecodeDifferent, EventMetadata, RuntimeMetadata, RuntimeMetadataPrefixed, StorageEntryMetadata,
@@ -35,11 +35,11 @@ pub enum MetadataError {
     #[error("Module with events not found")]
     ModuleWithEventsNotFound(u8),
     #[error("Call not found")]
-    CallNotFound(&'static str),
+    CallNotFound(String),
     #[error("Event not found")]
     EventNotFound(u8),
     #[error("Storage not found")]
-    StorageNotFound(&'static str),
+    StorageNotFound(String),
     #[error("Storage type error")]
     StorageTypeError,
     #[error("Map value type error")]
@@ -149,8 +149,8 @@ impl Metadata {
 
     pub fn storage_value_key(
         &self,
-        storage_prefix: &'static str,
-        storage_key_name: &'static str,
+        storage_prefix: &str,
+        storage_key_name: &str,
     ) -> Result<StorageKey, MetadataError> {
         Ok(self
             .module(storage_prefix)?
@@ -159,40 +159,40 @@ impl Metadata {
             .key())
     }
 
-    pub fn storage_map_key<K: Encode, V: Decode + Clone>(
+    pub fn storage_map_key<K: Encode>(
         &self,
-        storage_prefix: &'static str,
-        storage_key_name: &'static str,
+        storage_prefix: &str,
+        storage_key_name: &str,
         map_key: K,
     ) -> Result<StorageKey, MetadataError> {
         Ok(self
             .module(storage_prefix)?
             .storage(storage_key_name)?
-            .get_map::<K, V>()?
+            .get_map::<K>()?
             .key(map_key))
     }
 
     pub fn storage_map_key_prefix(
         &self,
-        storage_prefix: &'static str,
-        storage_key_name: &'static str,
+        storage_prefix: &str,
+        storage_key_name: &str,
     ) -> Result<StorageKey, MetadataError> {
         self.module(storage_prefix)?
             .storage(storage_key_name)?
             .get_map_prefix()
     }
 
-    pub fn storage_double_map_key<K: Encode, Q: Encode, V: Decode + Clone>(
+    pub fn storage_double_map_key<K: Encode, Q: Encode>(
         &self,
-        storage_prefix: &'static str,
-        storage_key_name: &'static str,
+        storage_prefix: &str,
+        storage_key_name: &str,
         first: K,
         second: Q,
     ) -> Result<StorageKey, MetadataError> {
         Ok(self
             .module(storage_prefix)?
             .storage(storage_key_name)?
-            .get_double_map::<K, Q, V>()?
+            .get_double_map::<K, Q>()?
             .key(first, second))
     }
 }
@@ -206,10 +206,10 @@ pub struct ModuleMetadata {
 }
 
 impl ModuleMetadata {
-    pub fn storage(&self, key: &'static str) -> Result<&StorageMetadata, MetadataError> {
+    pub fn storage(&self, key: &str) -> Result<&StorageMetadata, MetadataError> {
         self.storage
             .get(key)
-            .ok_or(MetadataError::StorageNotFound(key))
+            .ok_or(MetadataError::StorageNotFound(key.into()))
     }
 }
 
@@ -279,9 +279,9 @@ pub struct StorageMetadata {
 }
 
 impl StorageMetadata {
-    pub fn get_double_map<K: Encode, Q: Encode, V: Decode + Clone>(
+    pub fn get_double_map<K: Encode, Q: Encode>(
         &self,
-    ) -> Result<StorageDoubleMap<K, Q, V>, MetadataError> {
+    ) -> Result<StorageDoubleMap<K, Q>, MetadataError> {
         match &self.ty {
             StorageEntryType::DoubleMap {
                 hasher,
@@ -293,9 +293,6 @@ impl StorageMetadata {
                 let hasher1 = hasher.to_owned();
                 let hasher2 = key2_hasher.to_owned();
 
-                let default = Decode::decode(&mut &self.default[..])
-                    .map_err(|_| MetadataError::MapValueTypeError)?;
-
                 info!(
                     "map for '{}' '{}' has hasher1 {:?} hasher2 {:?}",
                     self.module_prefix, self.storage_prefix, hasher1, hasher2
@@ -307,20 +304,17 @@ impl StorageMetadata {
                     storage_prefix,
                     hasher: hasher1,
                     key2_hasher: hasher2,
-                    default,
                 })
             }
             _ => Err(MetadataError::StorageTypeError),
         }
     }
-    pub fn get_map<K: Encode, V: Decode + Clone>(&self) -> Result<StorageMap<K, V>, MetadataError> {
+    pub fn get_map<K: Encode>(&self) -> Result<StorageMap<K>, MetadataError> {
         match &self.ty {
             StorageEntryType::Map { hasher, .. } => {
                 let module_prefix = self.module_prefix.as_bytes().to_vec();
                 let storage_prefix = self.storage_prefix.as_bytes().to_vec();
                 let hasher = hasher.to_owned();
-                let default = Decode::decode(&mut &self.default[..])
-                    .map_err(|_| MetadataError::MapValueTypeError)?;
 
                 info!(
                     "map for '{}' '{}' has hasher {:?}",
@@ -331,7 +325,6 @@ impl StorageMetadata {
                     module_prefix,
                     storage_prefix,
                     hasher,
-                    default,
                 })
             }
             _ => Err(MetadataError::StorageTypeError),
@@ -378,39 +371,33 @@ impl StorageValue {
 }
 
 #[derive(Clone, Debug)]
-pub struct StorageMap<K, V> {
+pub struct StorageMap<K> {
     _marker: PhantomData<K>,
     module_prefix: Vec<u8>,
     storage_prefix: Vec<u8>,
     hasher: StorageHasher,
-    default: V,
 }
 
-impl<K: Encode, V: Decode + Clone> StorageMap<K, V> {
+impl<K: Encode> StorageMap<K> {
     pub fn key(&self, key: K) -> StorageKey {
         let mut bytes = sp_core::twox_128(&self.module_prefix).to_vec();
         bytes.extend(&sp_core::twox_128(&self.storage_prefix)[..]);
         bytes.extend(key_hash(&key, &self.hasher));
         StorageKey(bytes)
     }
-
-    pub fn default(&self) -> V {
-        self.default.clone()
-    }
 }
 
 #[derive(Clone, Debug)]
-pub struct StorageDoubleMap<K, Q, V> {
+pub struct StorageDoubleMap<K, Q> {
     _marker: PhantomData<K>,
     _marker2: PhantomData<Q>,
     module_prefix: Vec<u8>,
     storage_prefix: Vec<u8>,
     hasher: StorageHasher,
     key2_hasher: StorageHasher,
-    default: V,
 }
 
-impl<K: Encode, Q: Encode, V: Decode + Clone> StorageDoubleMap<K, Q, V> {
+impl<K: Encode, Q: Encode> StorageDoubleMap<K, Q> {
     pub fn key(&self, key1: K, key2: Q) -> StorageKey {
         let mut bytes = sp_core::twox_128(&self.module_prefix).to_vec();
         bytes.extend(&sp_core::twox_128(&self.storage_prefix)[..]);
@@ -418,10 +405,6 @@ impl<K: Encode, Q: Encode, V: Decode + Clone> StorageDoubleMap<K, Q, V> {
         bytes.extend(key_hash(&key2, &self.key2_hasher));
         StorageKey(bytes)
     }
-
-    pub fn default(&self) -> V {
-        self.default.clone()
-    }
 }
 
 #[derive(Clone, Debug)]
